---
title: <span class="badge object-type-scalar"></span> Henry
---
# <span class="badge object-type-scalar"></span> Henry

Energy: Henry (H)

## Definition

```python
# Energy: Henry (H)
Henry: typing.Literal["henry"] = "henry"
```
